==> git-cola-1.7.2.tar.gz: git-cola-1.7.2/cola/signals.py <==
add_signoff = 'add_signoff'
amend = 'amend'
amend_mode = 'amend_mode'
apply_diff_selection = 'apply_diff_selection'
apply_patches = 'apply_patches'
commit = 'commit'
commits_selected = 'commits_selected'
confirm = 'confirm'
critical = 'critical'
edit = 'edit'
checkout = 'checkout'
checkout_branch = 'checkout_branch'
cherry_pick = 'cherry_pick'
clone = 'clone'
delete = 'delete'
ignore = 'ignore'
delete_branch = 'delete_branch'
diff = 'diff'
diff_expr_mode = 'diff_expr_mode'
diff_mode = 'diff_mode'
diff_staged = 'diff_staged'
diffstat = 'diffstat'
difftool = 'difftool'
format_patch = 'format_patch'
grep = 'grep'
information = 'information'
log_cmd = 'log_cmd'
load_commit_message = 'load_commit_message'
load_commit_template = 'load_commit_template'
load_previous_message = 'load_previous_message'
mergetool = 'mergetool'
mode = 'mode'
modified_summary = 'modified_summary'
open_repo = 'open_repo'
question = 'question'
redo = 'redo'
rescan = 'rescan'
rescan_and_refresh = 'rescan_and_refresh'
reset_mode = 'reset_mode'
review_branch_mode = 'review_branch_mode'
run_config_action = 'run_config_action'
run_command = 'run_command'
set_diff_text = 'set_diff_text'
show_untracked = 'show_untracked'
signoff = 'signoff'
stage = 'stage'
stage_diffs = 'stage_diffs'
stage_modified = 'stage_modified'
stage_unmerged = 'stage_unmerged'
stage_untracked = 'stage_untracked'
staged_summary = 'staged_summary'
tag = 'tag'
unmerged_summary = 'unmerged_summary'
undo = 'undo'
undo_diffs = 'undo_diffs'
unstage = 'unstage'
unstage_diffs = 'unstage_diffs'
unstage_all = 'unstage_all'
unstage_selected = 'unstage_selected'
untracked_summary = 'untracked_summary'
update_file_status = 'update_file_status'
visualize_all = 'visualize_all'
visualize_current = 'visualize_current'
visualize_paths = 'visualize_paths'
visualize_revision = 'visualize_revision'

==> git-cola_1.8.0.orig.tar.gz: git-cola-1.8.0/cola/signals.py <==
add_signoff = 'add_signoff'
amend = 'amend'
amend_mode = 'amend_mode'
apply_diff_selection = 'apply_diff_selection'
apply_patches = 'apply_patches'
commit = 'commit'
commits_selected = 'commits_selected'
confirm = 'confirm'
critical = 'critical'
edit = 'edit'
checkout = 'checkout'
checkout_branch = 'checkout_branch'
cherry_pick = 'cherry_pick'
clone = 'clone'
delete = 'delete'
ignore = 'ignore'
delete_branch = 'delete_branch'
diff = 'diff'
diff_staged = 'diff_staged'
diffstat = 'diffstat'
difftool = 'difftool'
format_patch = 'format_patch'
information = 'information'
log_cmd = 'log_cmd'
load_commit_message = 'load_commit_message'
load_commit_template = 'load_commit_template'
load_previous_message = 'load_previous_message'
mergetool = 'mergetool'
mode = 'mode'
modified_summary = 'modified_summary'
open_default_app = 'open_default_app'
open_repo = 'open_repo'
question = 'question'
redo = 'redo'
rescan = 'rescan'
rescan_and_refresh = 'rescan_and_refresh'
reset_mode = 'reset_mode'
review_branch_mode = 'review_branch_mode'
run_config_action = 'run_config_action'
run_command = 'run_command'
set_diff_text = 'set_diff_text'
show_untracked = 'show_untracked'
signoff = 'signoff'
stage = 'stage'
stage_diffs = 'stage_diffs'
stage_modified = 'stage_modified'
stage_unmerged = 'stage_unmerged'
stage_untracked = 'stage_untracked'
staged_summary = 'staged_summary'
tag = 'tag'
unmerged_summary = 'unmerged_summary'
undo = 'undo'
undo_diffs = 'undo_diffs'
unstage = 'unstage'
unstage_diffs = 'unstage_diffs'
unstage_all = 'unstage_all'
unstage_selected = 'unstage_selected'
untrack = 'untrack'
untracked_summary = 'untracked_summary'
update_file_status = 'update_file_status'
visualize_all = 'visualize_all'
visualize_current = 'visualize_current'
visualize_paths = 'visualize_paths'
visualize_revision = 'visualize_revision'
